package javax.swing;

import java.util.EventListener;
import javax.swing.event.ChangeListener;
import javax.swing.event.EventListenerList;
import javax.swing.event.ChangeEvent;
import java.io.Serializable;

public class DefaultSingleSelectionModel implements SingleSelectionModel, Serializable
{
    protected transient ChangeEvent changeEvent;
    protected EventListenerList listenerList;
    private int index;
    
    public DefaultSingleSelectionModel() {
        this.changeEvent = null;
        this.listenerList = new EventListenerList();
        this.index = -1;
    }
    
    @Override
    public int getSelectedIndex() {
        return this.index;
    }
    
    @Override
    public void setSelectedIndex(int index) {
        if (this.index != index) {
            this.index = index;
            this.fireStateChanged();
        }
    }
    
    @Override
    public void clearSelection() {
        this.setSelectedIndex(-1);
    }
    
    @Override
    public boolean isSelected() {
        boolean n = false;
        if (this.getSelectedIndex() != -1) {
            n = true;
        }
        return n;
    }
    
    @Override
    public void addChangeListener(ChangeListener l) {
        this.listenerList.add(ChangeListener.class, l);
    }
    
    @Override
    public void removeChangeListener(ChangeListener l) {
        this.listenerList.remove(ChangeListener.class, l);
    }
    
    public ChangeListener[] getChangeListeners() {
        return (ChangeListener[])this.listenerList.getListeners(ChangeListener.class);
    }
    
    protected void fireStateChanged() {
        Object[] listenerList = this.listenerList.getListenerList();
        for (int i = listenerList.length - 2; i >= 0; i -= 2) {
            if (listenerList[i] == ChangeListener.class) {
                if (this.changeEvent == null) {
                    this.changeEvent = new ChangeEvent(this);
                }
                ((ChangeListener)listenerList[i + 1]).stateChanged(this.changeEvent);
            }
        }
    }
    
    public <T extends EventListener> T[] getListeners(Class<T> t) {
        return this.listenerList.getListeners(t);
    }
}
